// Figure 1.  Predicted probabilities

use "data group success.dta", clear
gen ly = ln(gdppercapita)
gen lpop = ln(pop)
gen lelv = ln(elevation) 
gen nontercst = nonterr_casualties/pop
replace nontercst=nontercst*1000000  // 78% zeros
bysort gid: egen maxsize=max(peak_size)
gen lnpeaksize=ln(maxsize)
foreach var of varlist ly lpop polity {
	gen `var'1=`var'
	}
gen pt=(pt_or_v=="pt")	// 84 groups
gen vic=(pt_or_v=="v")	// 19 groups
replace pt=. if endstr==0
replace vic=. if endstr==0

keep gid y_start y_end endstr pt vic lnpeaksize num_base lelv tropics landlock ///
	pch tch ercsr sq left nat right rel EAP ECA LAC MENA NA SAS SSA shr_trans ///
	nontercst competitor diversity ly lpop polity ly1 lpop1 polity1

collapse (max) y_start y_end endstr pt vic lnpeaksize num_base lelv tropics ///
	landlock pch tch ercsr sq left nat right rel EAP ECA LAC MENA NA SAS SSA ///
	(mean) shr_trans nontercst competitor diversity ///
	(first) ly lpop polity ///
	(firstnm) ly1 lpop1 polity1, by(gid)
gen duration=y_end-y_start
replace duration=2016-y_start if duration==. 
gen lnontercst=ln(nontercst+1)
gen lcomp=ln(competitor+1)
gen end=(endstr!=0)
gen success=(endstr==3)
replace success=. if endstr==0

qui probit end lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	lnontercst num_base duration i.ercsr i.pch i.tch ly1 lpop1 polity1 ///
	lelv tropics landlock EAP ECA LAC NA SAS SSA, rob
est store end
qui probit success lnpeaksize i.left i.nat i.right competitor shr_trans diversity ///
	i.ercsr i.pch i.tch lpop1 polity1, rob
est store success

// Size
est restore end
margins, at(lnpeaksize=(0(1)10)) post //overall effect of size: predicted prob
est store size_end 
est restore success
margins, at(lnpeaksize=(0(1)10)) post
est store size_success
coefplot (size_end, label(End)) (size_success, label(Success)), ///
	vertical recast(line) ciopts(recast(rspike)) xtitle(log(Size)) ///
	ytitle(Probability) title(Predictive Margins with 95% CI) ylabel(,nogrid) ///
	xlabel(1 "0" 2 "1" 3 "2" 4 "3" 5 "4" 6 "5" 7 "6" 8 "7" 9 "8" 10 "9" 11 "10") 

// Competitor
est restore end
margins, at(competitor=(1(1)66)) post //overall effect of competitor: predicted prob
est store comp_end 
est restore success
margins, at(competitor=(1(1)66)) post
est store comp_success
coefplot (comp_end, label(End)) (comp_success, label(Success)), ///
	vertical recast(line) ciopts(recast(rspike)) xtitle(Number of other groups) ///
	ytitle(Probability) title(Predictive Margins with 95% CI) ylabel(,nogrid) ///
	xlabel(0(5)66) yline(0)

// Transnat. Share
est restore end
margins, at(shr_trans=(0(0.1)1)) post //overall effect of Trans. share: predicted prob
est store shrtr_end 
est restore success
margins, at(shr_trans=(0(0.1)1)) post
est store shrtr_success
coefplot (shrtr_end, label(End)) (shrtr_success, label(Success)), ///
	vertical recast(line) ciopts(recast(rspike)) xtitle(Trans. terr. share) ///
	ytitle(Probability) title(Predictive Margins with 95% CI) ylabel(,nogrid) ///
	xlabel(1 "0" 2 "0.1" 3 "0.2" 4 "0.3" 5 "0.4" 6 "0.5" 7 "0.6" 8 "0.7" ///
	9 "0.8" 10 "0.9" 11 "1")

// Number of bases
est restore end
margins, at(num_base=(1(1)10)) post //overall effect of competitor: predicted prob
est store nbase_end
coefplot (nbase_end, label(End)), ///
	vertical recast(line) ciopts(recast(rspike)) xtitle(Number of bases) ///
	ytitle(Probability of ending) title(Predictive Margins with 95% CI) ///
	ylabel(,nogrid) xlabel(0(1)10)

// Size & ideology
est restore end
margins, at(lnpeaksize=(0(1)10) left=(1) nat=(0) right=(0)) post
est store left_end 
est restore success
margins, at(lnpeaksize=(0(1)10) left=(1) nat=(0) right=(0)) post
est store left_success
	
est restore end
margins, at(lnpeaksize=(0(1)10) left=(0) nat=(1) right=(0)) post
est store nat_end 
est restore success
margins, at(lnpeaksize=(0(1)10) left=(0) nat=(1) right=(0)) post
est store nat_success
	
est restore end
margins, at(lnpeaksize=(0(1)10) left=(0) nat=(0) right=(1)) post
est store right_end 
est restore success
margins, at(lnpeaksize=(0(1)10) left=(0) nat=(0) right=(1)) post
est store right_success

est restore end
margins, at(lnpeaksize=(0(1)10) left=(0) nat=(0) right=(0)) post
est store rel_end 
est restore success
margins, at(lnpeaksize=(0(1)10) left=(0) nat=(0) right=(0)) post
est store rel_success

coefplot (left_end, label(Left=1 Nat=0 Right=0)) ///
	(nat_end, label(Left=0 Nat=1 Right=0)) ///
	(right_end, label(Left=0 Nat=0 Right=1)) ///
	(rel_end, label(Left=0 Nat=0 Right=0)), ///
	vertical recast(line) ciopts(recast(rspike)) xtitle(log(Size)) ///
	ytitle(Probability of ending) title(Predictive Margins with 95% CI) ylabel(,nogrid) ///
	xlabel(1 "0" 2 "1" 3 "2" 4 "3" 5 "4" 6 "5" 7 "6" 8 "7" 9 "8" 10 "9" 11 "10")

coefplot (left_success, label(Left=1 Nat=0 Right=0)) ///
	(nat_success, label(Left=0 Nat=1 Right=0)) ///
	(right_success, label(Left=0 Nat=0 Right=1)) ///
	(rel_success, label(Left=0 Nat=0 Right=0)), ///
	vertical recast(line) ciopts(recast(rspike)) xtitle(log(Size)) ///
	ytitle(Probability of success) title(Predictive Margins with 95% CI) ylabel(,nogrid) ///
	xlabel(1 "0" 2 "1" 3 "2" 4 "3" 5 "4" 6 "5" 7 "6" 8 "7" 9 "8" 10 "9" 11 "10")
